==> pycharmPC-261.17801.74-EAP-CANDIDATE.zip: cmath.py <==
# encoding: utf-8
# module cmath
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/cmath.cpython-37m-darwin.so
# by generator 1.147
"""
This module provides access to mathematical functions for complex
numbers.
"""
# no imports

# Variables with simple values
e = 2.718281828459045

inf = inf

nan = nan

pi = 3.141592653589793

tau = 6.283185307179586

# functions

def acos(*args, **kwargs): # real signature unknown
    """ Return the arc cosine of z. """
    pass

def acosh(*args, **kwargs): # real signature unknown
    """ Return the inverse hyperbolic cosine of z. """
    pass

def asin(*args, **kwargs): # real signature unknown
    """ Return the arc sine of z. """
    pass

def asinh(*args, **kwargs): # real signature unknown
    """ Return the inverse hyperbolic sine of z. """
    pass

def atan(*args, **kwargs): # real signature unknown
    """ Return the arc tangent of z. """
    pass

def atanh(*args, **kwargs): # real signature unknown
    """ Return the inverse hyperbolic tangent of z. """
    pass

def cos(*args, **kwargs): # real signature unknown
    """ Return the cosine of z. """
    pass

def cosh(*args, **kwargs): # real signature unknown
    """ Return the hyperbolic cosine of z. """
    pass

def exp(*args, **kwargs): # real signature unknown
    """ Return the exponential value e**z. """
    pass

def isclose(*args, **kwargs): # real signature unknown
    """
    Determine whether two complex numbers are close in value.
    
      rel_tol
        maximum difference for being considered "close", relative to the
        magnitude of the input values
      abs_tol
        maximum difference for being considered "close", regardless of the
        magnitude of the input values
    
    Return True if a is close in value to b, and False otherwise.
    
    For the values to be considered close, the difference between them must be
    smaller than at least one of the tolerances.
    
    -inf, inf and NaN behave similarly to the IEEE 754 Standard. That is, NaN is
    not close to anything, even itself. inf and -inf are only close to themselves.
    """
    pass

def isfinite(*args, **kwargs): # real signature unknown
    """ Return True if both the real and imaginary parts of z are finite, else False. """
    pass

def isinf(*args, **kwargs): # real signature unknown
    """ Checks if the real or imaginary part of z is infinite. """
    pass

def isnan(*args, **kwargs): # real signature unknown
    """ Checks if the real or imaginary part of z not a number (NaN). """
    pass

def log(*args, **kwargs): # real signature unknown
    """
    The logarithm of z to the given base.
    
    If the base not specified, returns the natural logarithm (base e) of z.
    """
    pass

def log10(*args, **kwargs): # real signature unknown
    """ Return the base-10 logarithm of z. """
    pass

def phase(*args, **kwargs): # real signature unknown
    """ Return argument, also known as the phase angle, of a complex. """
    pass

def polar(*args, **kwargs): # real signature unknown
    """
    Convert a complex from rectangular coordinates to polar coordinates.
    
    r is the distance from 0 and phi the phase angle.
    """
    pass

def rect(*args, **kwargs): # real signature unknown
    """ Convert from polar coordinates to rectangular coordinates. """
    pass

def sin(*args, **kwargs): # real signature unknown
    """ Return the sine of z. """
    pass

def sinh(*args, **kwargs): # real signature unknown
    """ Return the hyperbolic sine of z. """
    pass

def sqrt(*args, **kwargs): # real signature unknown
    """ Return the square root of z. """
    pass

def tan(*args, **kwargs): # real signature unknown
    """ Return the tangent of z. """
    pass

def tanh(*args, **kwargs): # real signature unknown
    """ Return the hyperbolic tangent of z. """
    pass

# no classes
# variables with complex values

infj = None # (!) real value is 'infj'

nanj = None # (!) real value is 'nanj'

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x105585388>'

__spec__ = None # (!) real value is "ModuleSpec(name='cmath', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x105585388>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/cmath.cpython-37m-darwin.so')"

==> pycharmPC-261.17801.91-EAP-CANDIDATE.zip: cmath.py <==
# encoding: utf-8
# module cmath
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python310/lib/python3.10/lib-dynload/cmath.cpython-310-darwin.so
# by generator 1.147
"""
This module provides access to mathematical functions for complex
numbers.
"""
# no imports

# Variables with simple values
e = 2.718281828459045

inf = inf

nan = nan

pi = 3.141592653589793

tau = 6.283185307179586

# functions

def acos(*args, **kwargs): # real signature unknown
    """ Return the arc cosine of z. """
    pass

def acosh(*args, **kwargs): # real signature unknown
    """ Return the inverse hyperbolic cosine of z. """
    pass

def asin(*args, **kwargs): # real signature unknown
    """ Return the arc sine of z. """
    pass

def asinh(*args, **kwargs): # real signature unknown
    """ Return the inverse hyperbolic sine of z. """
    pass

def atan(*args, **kwargs): # real signature unknown
    """ Return the arc tangent of z. """
    pass

def atanh(*args, **kwargs): # real signature unknown
    """ Return the inverse hyperbolic tangent of z. """
    pass

def cos(*args, **kwargs): # real signature unknown
    """ Return the cosine of z. """
    pass

def cosh(*args, **kwargs): # real signature unknown
    """ Return the hyperbolic cosine of z. """
    pass

def exp(*args, **kwargs): # real signature unknown
    """ Return the exponential value e**z. """
    pass

def isclose(*args, **kwargs): # real signature unknown
    """
    Determine whether two complex numbers are close in value.
    
      rel_tol
        maximum difference for being considered "close", relative to the
        magnitude of the input values
      abs_tol
        maximum difference for being considered "close", regardless of the
        magnitude of the input values
    
    Return True if a is close in value to b, and False otherwise.
    
    For the values to be considered close, the difference between them must be
    smaller than at least one of the tolerances.
    
    -inf, inf and NaN behave similarly to the IEEE 754 Standard. That is, NaN is
    not close to anything, even itself. inf and -inf are only close to themselves.
    """
    pass

def isfinite(*args, **kwargs): # real signature unknown
    """ Return True if both the real and imaginary parts of z are finite, else False. """
    pass

def isinf(*args, **kwargs): # real signature unknown
    """ Checks if the real or imaginary part of z is infinite. """
    pass

def isnan(*args, **kwargs): # real signature unknown
    """ Checks if the real or imaginary part of z not a number (NaN). """
    pass

def log(z, base=None): # real signature unknown; restored from __doc__
    """
    log(z[, base]) -> the logarithm of z to the given base.
    
    If the base not specified, returns the natural logarithm (base e) of z.
    """
    pass

def log10(*args, **kwargs): # real signature unknown
    """ Return the base-10 logarithm of z. """
    pass

def phase(*args, **kwargs): # real signature unknown
    """ Return argument, also known as the phase angle, of a complex. """
    pass

def polar(*args, **kwargs): # real signature unknown
    """
    Convert a complex from rectangular coordinates to polar coordinates.
    
    r is the distance from 0 and phi the phase angle.
    """
    pass

def rect(*args, **kwargs): # real signature unknown
    """ Convert from polar coordinates to rectangular coordinates. """
    pass

def sin(*args, **kwargs): # real signature unknown
    """ Return the sine of z. """
    pass

def sinh(*args, **kwargs): # real signature unknown
    """ Return the hyperbolic sine of z. """
    pass

def sqrt(*args, **kwargs): # real signature unknown
    """ Return the square root of z. """
    pass

def tan(*args, **kwargs): # real signature unknown
    """ Return the tangent of z. """
    pass

def tanh(*args, **kwargs): # real signature unknown
    """ Return the hyperbolic tangent of z. """
    pass

# no classes
# variables with complex values

infj = None # (!) real value is 'infj'

nanj = None # (!) real value is 'nanj'

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x10130c850>'

__spec__ = None # (!) real value is "ModuleSpec(name='cmath', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x10130c850>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python310/lib/python3.10/lib-dynload/cmath.cpython-310-darwin.so')"
